@@ -4,7 +4,7 @@ from typing import List
 from movado.mab_controller import MabController  # pylint: disable=unused-import
 
 # noinspection PyUnresolvedReferences
-from movado.meta_controller import MetaController  # pylint: disable=unused-import
+from movado.voting_controller import VotingController  # pylint: disable=unused-import
 
 # noinspection PyUnresolvedReferences
 from movado.distance_controller import (
